aboutsummaryrefslogtreecommitdiffstats
path: root/feature-pooling-messages/src/test/java/org/onap
diff options
context:
space:
mode:
authoradheli.tavares <adheli.tavares@est.tech>2024-04-24 10:27:48 +0100
committeradheli.tavares <adheli.tavares@est.tech>2024-04-24 10:29:02 +0100
commit29065eadcfd111c6fefecdbed38e3ef27bd068ea (patch)
tree82f09dd455bf70d7ea29fe0f9e6bf52eb0d10849 /feature-pooling-messages/src/test/java/org/onap
parent5bd2e9091fa75bc41fce1667f5deb46ac5e94380 (diff)
Fix topic configurations.
- adjust kafka configurations - remove UEB references Issue-ID: POLICY-4955 Change-Id: Ie3ff62a0ba5531ae4c0d123f214a50bb7f721807 Signed-off-by: adheli.tavares <adheli.tavares@est.tech>
Diffstat (limited to 'feature-pooling-messages/src/test/java/org/onap')
-rw-r--r--feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/EndToEndFeatureTest.java20
-rw-r--r--feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/FeatureTest.java9
2 files changed, 14 insertions, 15 deletions
diff --git a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/FeatureTest.java b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/FeatureTest.java
index c507b68a..f1b48b3e 100644
--- a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/FeatureTest.java
+++ b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/FeatureTest.java
@@ -68,7 +68,6 @@ import org.slf4j.LoggerFactory;
* End-to-end tests of the pooling feature. Launches one or more "hosts", each one having
* its own feature object. Uses real feature objects. However, the following are not:
* <dl>
- * <dt>DMaaP sources and sinks</dt>
* <dd>simulated using queues. There is one queue for the external topic, and one queue
* for each host's internal topic. Messages published to the "admin" channel are simply
* sent to all of the hosts' internal topic queues</dd>
@@ -430,13 +429,13 @@ class FeatureTest {
private final AtomicBoolean sawMsg = new AtomicBoolean(false);
/**
- * This host's internal "DMaaP" topic.
+ * This host's internal topic.
*/
private final BlockingQueue<String> msgQueue = new LinkedBlockingQueue<>();
/**
- * Queue for the external "DMaaP" topic.
+ * Queue for the external topic.
*/
@Getter
private final BlockingQueue<String> externalTopic = new LinkedBlockingQueue<String>();
@@ -486,7 +485,7 @@ class FeatureTest {
/**
* Starts threads for the host so that it begins consuming from both the external
- * "DMaaP" topic and its own internal "DMaaP" topic.
+ * topic and its own internal topic.
*/
public void start() {
@@ -987,7 +986,7 @@ class FeatureTest {
}
/**
- * DMaaP Manager with overrides.
+ * TopicManager with overrides.
*/
private static class TopicMessageManagerImpl extends TopicMessageManager {
diff --git a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/EndToEndFeatureTest.java b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/EndToEndFeatureTest.java
index ac2b31a8..1ad5d513 100644
--- a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/EndToEndFeatureTest.java
+++ b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/EndToEndFeatureTest.java
@@ -64,11 +64,11 @@ import org.slf4j.LoggerFactory;
/**
* End-to-end tests of the pooling feature. Launches one or more "hosts", each one having its own
- * feature object. Uses real feature objects, as well as real DMaaP sources and sinks. However, the
+ * feature object. Uses real feature objects, as well as real sources and sinks. However, the
* following are not: <dl> <dt>PolicyEngine, PolicyController, DroolsController</dt> <dd>mocked</dd>
* </dl>
*
* <p>The following fields must be set before executing this: <ul> <li>UEB_SERVERS</li>
* <li>INTERNAL_TOPIC</li> <li>EXTERNAL_TOPIC</li> </ul>
*/
public class EndToEndFeatureTest {
@@ -252,18 +252,18 @@ public class EndToEndFeatureTest {
private static Properties makeSourceProperties(String topic) {
Properties props = new Properties();
- props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS, topic);
+ props.setProperty(PolicyEndPointProperties.PROPERTY_KAFKA_SOURCE_TOPICS, topic);
- props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS + "." + topic
+ props.setProperty(PolicyEndPointProperties.PROPERTY_KAFKA_SOURCE_TOPICS + "." + topic
+ PolicyEndPointProperties.PROPERTY_TOPIC_SERVERS_SUFFIX, SERVER);
- props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS + "." + topic
+ props.setProperty(PolicyEndPointProperties.PROPERTY_KAFKA_SOURCE_TOPICS + "." + topic
+ PolicyEndPointProperties.PROPERTY_TOPIC_SOURCE_FETCH_LIMIT_SUFFIX, FETCH_LIMIT);
- props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS + "." + topic
+ props.setProperty(PolicyEndPointProperties.PROPERTY_KAFKA_SOURCE_TOPICS + "." + topic
+ PolicyEndPointProperties.PROPERTY_MANAGED_SUFFIX, "false");
if (EXTERNAL_TOPIC.equals(topic)) {
// consumer group is a constant
- props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS + "." + topic
+ props.setProperty(PolicyEndPointProperties.PROPERTY_KAFKA_SOURCE_TOPICS + "." + topic
+ PolicyEndPointProperties.PROPERTY_TOPIC_SOURCE_CONSUMER_GROUP_SUFFIX, EXTERNAL_GROUP);
// consumer instance is generated by the BusConsumer code
@@ -520,8 +520,8 @@ public class EndToEndFeatureTest {
}
/**
- * Starts threads for the host so that it begins consuming from both the external "DMaaP"
- * topic and its own internal "DMaaP" topic.
+ * Starts threads for the host so that it begins consuming from both the external
+ * topic and its own internal topic.
*/
public void start() {
feature.beforeStart(engine);
@@ -775,7 +775,7 @@ public class EndToEndFeatureTest {
}
/**
- * DMaaP Manager with overrides.
+ * TopicManager with overrides.
*/
private static class TopicMessageManagerImpl extends TopicMessageManager {
@@ -64,11 +64,11 @@ import org.slf4j.LoggerFactory;
* </dl>
*
- * <p>The following fields must be set before executing this: <ul> <li>UEB_SERVERS</li>
+ * <p>The following fields must be set before executing this: <ul> <li>SERVER</li>
* <li>INTERNAL_TOPIC</li> <li>EXTERNAL_TOPIC</li> </ul>
*/